package com.weChatmarket.controller;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.tomcat.util.http.fileupload.servlet.ServletFileUpload;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import com.weChatmarket.contens.BaseResult;
import com.weChatmarket.contens.ResultCodeEnum;
import com.weChatmarket.service.WxShopInforService;
import com.weChatmarket.service.WxShopItemService;
import com.wordnik.swagger.annotations.Api;
import com.wordnik.swagger.annotations.ApiOperation;

@RestController
@Api(value = "图片上传")
@RequestMapping(value = "/file")
public class FileUploadController {
	private static Logger logger = LoggerFactory.getLogger(FileUploadController.class);

	@Value("${uploadFile.resourceHandler}")
	private String resourceHandler; // 请求 url 中的资源映射，不推荐写死在代码中，最好提供可配置，如 /image/**

	@Value("${uploadFile.location}")
	private String location; // 上传文件保存的本地目录，使用@Value获取全局配置文件中配置的属性值，如 D:/wx/uploadFiles/

	@Value("${userLogin}")
	private String userLogin; // 用户名
	@Resource
	private WxShopInforService wxShopInforService;

	@Resource
	private WxShopItemService wxShopItemService;
	private final static long MAX_FILE_BYTES = 1024 * 1024 * 10L;

	@RequestMapping(value = "/upload", method = { RequestMethod.POST })
	@ApiOperation(value = "文件上传", notes = "文件上传", response = String.class)
	public BaseResult<Object> upload(HttpServletRequest request) {
		BaseResult<Object> br = new BaseResult<>();
		// 校验是否登入
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			br.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			br.setMsg("请先登入后，在进行操作");
			return br;
		}

		boolean isMultipart = ServletFileUpload.isMultipartContent(request);
		String fileServerPath = "";
		String name = "";
		if (isMultipart) {
			InputStream stream = null;
			FileOutputStream fs = null;
			MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
			List<MultipartFile> fileList = multipartRequest.getFiles("pic");
			for (MultipartFile multipartFile : fileList) {
				if (multipartFile.isEmpty()) {
					br.setCode(ResultCodeEnum.HTTP_ERROR.getCode());
					br.setMsg("上传图片为空，请重新上传！");
					return br;
				}
				if (multipartFile.getSize() > MAX_FILE_BYTES) {
					br.setCode(ResultCodeEnum.HTTP_ERROR.getCode());
					br.setMsg("图片大小超过10MB!,请修改后重新上传！");
					return br;
				}
				name = multipartFile.getOriginalFilename();
				if (name.length() > 40) {
					br.setCode(ResultCodeEnum.HTTP_ERROR.getCode());
					br.setMsg("文件名过长，超过40个字符!请修改后重新上传！");
					return br;
				}
				try {
					String basePath = request.getScheme() + "://" +
					// TODO
							"192.168.1.59:"
							// request.getServerName() + ":"
							+ request.getServerPort() + request.getContextPath();
					String fileName = System.currentTimeMillis() + multipartFile.getOriginalFilename().substring(
							multipartFile.getOriginalFilename().indexOf("."),
							multipartFile.getOriginalFilename().length());
					fileServerPath = basePath + resourceHandler.substring(0, resourceHandler.lastIndexOf("/") + 1)
							+ fileName;
					File saveFile = new File(location, String.valueOf(fileName));
					stream = multipartFile.getInputStream();
					fs = new FileOutputStream(saveFile);
					byte[] buffer = new byte[1024 * 1024];
					int byteread = 0;
					while ((byteread = stream.read(buffer)) != -1) {
						fs.write(buffer, 0, byteread);
					}
					fs.flush();
					fs.close();
					stream.close();
					// 记录上传的照片
					Date date = new Date();
					String strDateFormat = "yyyy-MM-dd HH:mm:ss";
					SimpleDateFormat sdf = new SimpleDateFormat(strDateFormat);
					logger.info(sdf.format(date) + "上传照片：" + multipartFile.getName());
				} catch (Exception e) {
					e.printStackTrace();
					try {
						if (fs != null) {
							fs.close();
						}
						if (stream != null) {
							stream.close();
						}
					} catch (Exception exc) {
						exc.printStackTrace();
					}
				}
			}
		}
		Map<String, Object> data = new HashMap<String, Object>();
		data.put("id", fileServerPath);
		data.put("name", name);
		br.setData(data);
		return br;
	}

	// @RequestMapping(value = "/cleanPhoto", method = { RequestMethod.POST })
	// @ApiOperation(value = "清理照片", notes = "清理照片", response = String.class)
	// public BaseResult<Object> cleanPhoto(HttpServletRequest request) {
	// BaseResult<Object> br = new BaseResult<>();
	// ArrayList<String> deleteFileList = new ArrayList<>();
	// File parentFile = new File(location);
	// File[] files = parentFile.listFiles();
	// // 收集商铺中所有在使用的照片
	// ArrayList<String> useFileList = new ArrayList<>();
	// List<WxShopInfor> listWxShopInfor =
	// wxShopInforService.findByNamedParamList(null);
	// String basePath = request.getScheme() + "://" + request.getServerName() + ":"
	// + request.getServerPort()
	// + request.getContextPath();
	// String fileServerPath = basePath + resourceHandler.substring(0,
	// resourceHandler.lastIndexOf("/") + 1);
	// for (WxShopInfor single : listWxShopInfor) {
	// // 店铺主图
	// if (!StringUtils.isEmpty(single.getShopMap())) {
	// useFileList.add(single.getShopMap().replace(fileServerPath, "").trim());
	// }
	// // 店铺现象图
	// if (!StringUtils.isEmpty(single.getShopImage())) {
	// String shopImage = single.getShopImage();
	// if (!StringUtils.isEmpty(shopImage)) {
	// String[] shopImageTeam = shopImage.split(",");
	// for (int i = 0; i < shopImageTeam.length; i++) {
	// if (!StringUtils.isEmpty(shopImageTeam[i])) {
	// useFileList.add(shopImageTeam[i].replace(fileServerPath, "").trim());
	// }
	// }
	// }
	// }
	// }
	// // 店铺商品明细图
	// List<WxShopItem> listwxShopItem =
	// wxShopItemService.findByNamedParamList(null);
	// for (WxShopItem single : listwxShopItem) {
	// if (!StringUtils.isEmpty(single.getPhotoId())) {
	// useFileList.add(single.getPhotoId().replace(fileServerPath, "").trim());
	// }
	// }
	//
	// for (File file : files) {
	// if (!file.isDirectory()) {
	// // 上传的文件不在商铺中, 就删除
	// Long sum = useFileList.stream().filter(name ->
	// name.trim().equals(file.getName().trim())).count();
	// if (sum == 0) {
	// if (file.delete()) {
	// logger.info(new Date() + "删除照片" + file.getName());
	// deleteFileList.add(file.getName());
	// }
	// }
	// }
	// }
	// br.setData(deleteFileList);
	// return br;
	// }
}