package com.weChatmarket.controller;

import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.weChatmarket.contens.BaseResult;
import com.weChatmarket.contens.ResultCodeEnum;
import com.weChatmarket.service.WxShopInforService;
import com.wordnik.swagger.annotations.Api;
import com.wordnik.swagger.annotations.ApiOperation;
import com.wordnik.swagger.annotations.ApiParam;

@RestController
@Api(value = "商铺信息维护", description = "商铺信息维护")
@RequestMapping(value = "/wxShopInfor")
public class WxShopInforController {
	@Value("${userLogin}")
	private String userLogin; // 用户名
	@Resource
	private WxShopInforService wxShopInforService;

	@RequestMapping(value = "/pageList", method = { RequestMethod.POST })
	@ApiOperation(value = "web端商城查询", notes = "web端商城查询", response = String.class)
	public BaseResult<Object> pageList(
			@ApiParam(value = "页码") @RequestParam(required = false, defaultValue = "1") Integer pageNum,
			@ApiParam(value = "每页数量") @RequestParam(required = false, defaultValue = "10") Integer pageSize,
			@ApiParam(value = "商铺名称或门牌号") @RequestParam(required = false) String searchValue) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopInforService.findPage(pageNum, pageSize, searchValue));
		return result;
	}

	@RequestMapping(value = "/findWxShopInforById", method = { RequestMethod.POST })
	@ApiOperation(value = "web端获取单个商城", notes = "web端获取单个商城", response = String.class)
	public BaseResult<Object> findWxShopInforById(@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopInforService.findWxShopInforDtoById(id));
		return result;
	}

	@RequestMapping(value = "/wxPageList", method = { RequestMethod.POST })
	@ApiOperation(value = "微信端商铺查询", notes = "微信端商铺查询", response = String.class)
	public BaseResult<Object> wxPageList(
			@ApiParam(value = "商铺名称或门牌号") @RequestParam(required = false) String searchValue,
			@ApiParam(value = "商铺的种类") @RequestParam(required = false) Long typeId,
			@ApiParam(value = "商铺的标签") @RequestParam(required = false) String label) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopInforService.wxPageList(searchValue, typeId, label));
		return result;
	}

	@RequestMapping(value = "/wxFindById", method = { RequestMethod.POST })
	@ApiOperation(value = "微信端获取单个商城", notes = "微信端获取单个商城", response = String.class)
	public BaseResult<Object> wxFindById(@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopInforService.wxFindById(id));
		return result;
	}

	@RequestMapping(value = "/addOrUpdate", method = { RequestMethod.POST })
	@ApiOperation(value = "商铺新增或修改", notes = "商铺新增或修改", response = String.class)
	public BaseResult<Object> addOrUpdate(HttpServletRequest request,
			@ApiParam(value = "主键ID") @RequestParam(required = true) Long id,
			@ApiParam(value = "商铺名称") @RequestParam(required = false) String name,
			@ApiParam(value = "门牌号") @RequestParam(required = false) String code,
			@ApiParam(value = "商铺种类id") @RequestParam(required = false) Long typeId,
			@ApiParam(value = "商铺标签ids") @RequestParam(required = false) List<String> labelIds,
			@ApiParam(value = "电话号码") @RequestParam(required = false) String telephone,
			@ApiParam(value = "店铺简介") @RequestParam(required = false) String introduce,
			@ApiParam(value = "微信联系方式") @RequestParam(required = false) String wechat,
			@ApiParam(value = "店铺主图") @RequestParam(required = false) String shopMap,
			@ApiParam(value = "店铺主图图片名称") @RequestParam(required = false) String shopMapName,
			@ApiParam(value = "置顶") @RequestParam(required = false) Integer top) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		boolean exist = wxShopInforService.checkWxShopInfor(id, code);
		if (exist) {
			// 存在就不允许创建，并返回错误信息
			result.setCode(ResultCodeEnum.HTTP_PARAMS_ERROR.getCode());
			result.setMsg("内容已经存在或者店铺号重复");
		} else {
			wxShopInforService.addOrUpdateWxShopInfor(id, name, code, typeId, labelIds, telephone, introduce, wechat,
					shopMap, shopMapName, top);
		}
		return result;
	}

	@RequestMapping(value = "/delete", method = { RequestMethod.POST })
	@ApiOperation(value = "商铺删除", notes = "商铺删除", response = String.class)
	public BaseResult<Object> delete(HttpServletRequest request,
			@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		wxShopInforService.updateStatusById(id);
		return result;
	}
}
