package com.weChatmarket.controller;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.weChatmarket.contens.BaseResult;
import com.weChatmarket.contens.ResultCodeEnum;
import com.weChatmarket.domain.WxShopItem;
import com.weChatmarket.page.BasePage;
import com.weChatmarket.service.WxShopItemService;
import com.wordnik.swagger.annotations.Api;
import com.wordnik.swagger.annotations.ApiOperation;
import com.wordnik.swagger.annotations.ApiParam;

@RestController
@Api(value = "商品图文维护", description = "商品图文维护")
@RequestMapping(value = "/wxShopItem")
public class WxShopItemController {
	@Value("${userLogin}")
	private String userLogin; // 用户名
	@Resource
	private WxShopItemService wxShopItemService;

	@RequestMapping(value = "/pageList", method = { RequestMethod.POST })
	@ApiOperation(value = "web端商铺商品详情查询", notes = "web端商铺商品详情查询", response = String.class)
	public BaseResult<BasePage<WxShopItem>> pageList(
			@ApiParam(value = " ") @RequestParam(required = false, defaultValue = "1") Integer pageNum,
			@ApiParam(value = "每页数量") @RequestParam(required = false, defaultValue = "20") Integer pageSize,
			@ApiParam(value = "商场主键ID") @RequestParam(required = false) Long pId) {
		BaseResult<BasePage<WxShopItem>> result = new BaseResult<>();
		result.setData(wxShopItemService.findPage(pageNum, pageSize, pId));
		return result;
	}

	@RequestMapping(value = "/findWxShopItemById", method = { RequestMethod.POST })
	@ApiOperation(value = "web端获取单个商铺商品详情", notes = "web端获取单个商铺商品详情", response = String.class)
	public BaseResult<Object> findWxShopItemById(@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopItemService.findById(id));
		return result;
	}

	@RequestMapping(value = "/findWxShopItemByPid", method = { RequestMethod.POST })
	@ApiOperation(value = "获取单个商品详情", notes = "获取单个商品图文", response = String.class)
	public BaseResult<Object> findWxShopItemByPid(@ApiParam(value = "父类主键") @RequestParam(required = true) Long pId) {
		BaseResult<Object> result = new BaseResult<>();
		WxShopItem wxShopItem = new WxShopItem();
		wxShopItem.setPId(pId);
		wxShopItem.setStatus(1);
		result.setData(wxShopItemService.findByNamedParamList(wxShopItem));
		return result;
	}

	@RequestMapping(value = "/addOrUpdate", method = { RequestMethod.POST })
	@ApiOperation(value = "商铺商品详情维护", notes = "商铺商品详情维护", response = String.class)
	public BaseResult<Object> addOrUpdate(HttpServletRequest request,
			@ApiParam(value = "主键ID") @RequestParam(required = true) Long id,
			@ApiParam(value = "商铺主键id") @RequestParam(required = true) Long pId,
			@ApiParam(value = "商品标题") @RequestParam(required = true) String title,
			@ApiParam(value = "商品内容") @RequestParam(required = true) String content,
			@ApiParam(value = "商品照片") @RequestParam(required = true) String photoId,
			@ApiParam(value = "商品照片名称") @RequestParam(required = true) String photoName) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		wxShopItemService.addOrUpdateWxShopItem(id, pId, title, content, photoId, photoName);
		return result;
	}

	@RequestMapping(value = "/delete", method = { RequestMethod.POST })
	@ApiOperation(value = "商铺商品详情删除", notes = "商铺商品详情删除", response = String.class)
	public BaseResult<Object> delete(HttpServletRequest request,
			@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		wxShopItemService.updateStatusById(id);
		return result;
	}
}
