package com.weChatmarket.controller;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.weChatmarket.contens.BaseResult;
import com.weChatmarket.contens.ResultCodeEnum;
import com.weChatmarket.domain.WxShopType;
import com.weChatmarket.page.BasePage;
import com.weChatmarket.service.WxShopTypeService;
import com.wordnik.swagger.annotations.Api;
import com.wordnik.swagger.annotations.ApiOperation;
import com.wordnik.swagger.annotations.ApiParam;

@RestController
@Api(value = "商城类别维护", description = "商城类别维护")
@RequestMapping(value = "/WxShopType")
public class WxShopTypeController {
	@Value("${userLogin}")
	private String userLogin; // 用户名
	@Resource
	private WxShopTypeService wxShopTypeService;

	@RequestMapping(value = "/typePageList", method = { RequestMethod.POST })
	@ApiOperation(value = "web商城经营的类别查询", notes = "web商城经营的类别查询", response = String.class)
	public BaseResult<BasePage<WxShopType>> typePageList(
			@ApiParam(value = "页码") @RequestParam(required = false, defaultValue = "1") Integer pageNum,
			@ApiParam(value = "每页数量") @RequestParam(required = false, defaultValue = "10") Integer pageSize) {
		BaseResult<BasePage<WxShopType>> result = new BaseResult<>();
		result.setData(wxShopTypeService.typePageList(pageNum, pageSize));
		return result;
	}

	@RequestMapping(value = "/typeList", method = { RequestMethod.POST })
	@ApiOperation(value = "web商城经营的类别", notes = "web商城经营的类别", response = String.class)
	public BaseResult<Object> typeList(@ApiParam(value = "种类名称") @RequestParam(required = false) String typename) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopTypeService.typeList(typename));
		return result;
	}

	@RequestMapping(value = "/lablePageList", method = { RequestMethod.POST })
	@ApiOperation(value = "web商城经营的标签查询", notes = "web商城经营的标签查询", response = String.class)
	public BaseResult<BasePage<WxShopType>> lablePageList(
			@ApiParam(value = "页码") @RequestParam(required = false, defaultValue = "1") Integer pageNum,
			@ApiParam(value = "每页数量") @RequestParam(required = false, defaultValue = "10") Integer pageSize,
			@ApiParam(value = "父类主键pId") @RequestParam(required = true) Long pId) {
		BaseResult<BasePage<WxShopType>> result = new BaseResult<>();
		result.setData(wxShopTypeService.lablePageList(pageNum, pageSize, pId));
		return result;
	}

	@RequestMapping(value = "/lableList", method = { RequestMethod.POST })
	@ApiOperation(value = "web商城经营的标签查询", notes = "web商城经营的标签查询", response = String.class)
	public BaseResult<Object> lableList(@ApiParam(value = "父类主键pId") @RequestParam(required = true) Long pId) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopTypeService.lableList(pId));
		return result;
	}

	@RequestMapping(value = "/wxTypeLableList", method = { RequestMethod.POST })
	@ApiOperation(value = "微信端查看商城类别标签查询", notes = "微信端查看商城类别标签查询", response = String.class)
	public BaseResult<Object> wxTypeLableList() {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopTypeService.wxTypeLableList());
		return result;
	}

	@RequestMapping(value = "/findWxShopTypeById", method = { RequestMethod.POST })
	@ApiOperation(value = "获取单个商城类别或标签", notes = "获取单个商城类别或标签", response = String.class)
	public BaseResult<Object> findWxShopTypeById(@ApiParam(value = "主键") @RequestParam(required = true) Long id) {
		BaseResult<Object> result = new BaseResult<>();
		result.setData(wxShopTypeService.findWxShopTypeById(id));
		return result;
	}

	@RequestMapping(value = "/addOrUpdate", method = { RequestMethod.POST })
	@ApiOperation(value = "商城类别|标签新增或修改", notes = "商城类别|标签新增或修改", response = String.class)
	public BaseResult<Object> addOrUpdate(HttpServletRequest request,
			@ApiParam(value = "主键id") @RequestParam(required = true) Long id,
			@ApiParam(value = "父类主键pId") @RequestParam(required = true) Long pId,
			@ApiParam(value = "类别|标签名称") @RequestParam(required = true) String typeName) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		boolean exist = wxShopTypeService.checkWxShopType(pId, typeName);
		if (exist) {
			// 存在就不允许创建，并返回错误信息
			result.setCode(ResultCodeEnum.HTTP_PARAMS_ERROR.getCode());
			result.setMsg("内容已经存在");
		} else {
			wxShopTypeService.addOrUpdateWxShopType(id, pId, typeName);
		}
		return result;
	}

	@RequestMapping(value = "/delete", method = { RequestMethod.POST })
	@ApiOperation(value = "商城类别标签删除", notes = "商城类别标签删除", response = String.class)
	public BaseResult<Object> delete(HttpServletRequest request,
			@ApiParam(value = "主键") @RequestParam(required = true) Long id,
			@ApiParam(value = "父类主键") @RequestParam(required = true) Long pId) {
		BaseResult<Object> result = new BaseResult<>();
		HttpSession session = request.getSession(false);
		if (null == session || !userLogin.equals(session.getAttribute("user"))) {
			result.setCode(ResultCodeEnum.HTTP_LOGIN.getCode());
			result.setMsg("请先登入后，在进行操作");
			return result;
		}
		wxShopTypeService.updateStatusById(id, pId);
		return result;
	}
}
