package com.weChatmarket.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import javax.annotation.Resource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.weChatmarket.dao.WxShopInforDao;
import com.weChatmarket.domain.WxShopInfor;
import com.weChatmarket.domain.WxShopItem;
import com.weChatmarket.domain.WxShopType;
import com.weChatmarket.dto.WxShopInforAppDto;
import com.weChatmarket.dto.WxShopInforDto;
import com.weChatmarket.page.BasePage;
import com.weChatmarket.service.WxShopInforService;
import com.weChatmarket.service.WxShopItemService;
import com.weChatmarket.service.WxShopTypeService;

/**
 * 微信商场店铺信息表 create by dongshize
 */
@Service("wxShopInforService")
public class WxShopInforServiceImpl extends BaseServiceImpl<WxShopInfor> implements WxShopInforService {

	@Autowired
	private WxShopInforDao wxShopInforDao;
	@Autowired
	private WxShopTypeService wxShopTypeService;
	@Resource
	private WxShopItemService wxShopItemService;

	@SuppressWarnings("unchecked")
	@Override
	public WxShopInforDao getDao() {
		return wxShopInforDao;
	}

	/**
	 * 所有商铺查询
	 * 
	 * @param pageNum
	 *            页码
	 * @param pageSize
	 *            每页数量
	 * @param searchValue
	 *            店铺名称 或 店铺门牌号
	 */
	@Override
	public BasePage<WxShopInforDto> findPage(Integer pageNum, Integer pageSize, String searchValue) {
		PageHelper.startPage(pageNum, pageSize);
		List<WxShopInforDto> list = wxShopInforDao.findPage(searchValue, null);
		List<WxShopType> shopTypeList = wxShopTypeService.findByNamedParamList(null);
		if (null != list && list.size() > 0) {
			// 查询有结果
			for (WxShopInforDto wxShopInforDto : list) {
				editWxShopInforDto(wxShopInforDto, shopTypeList);
			}

		}
		return new BasePage<WxShopInforDto>(list);
	}

	/**
	 * 商铺查询
	 * 
	 * @param searchValue
	 *            店铺名称 或 店铺门牌号
	 * @param typeId
	 *            商铺的种类
	 * @param label
	 *            商铺的标签
	 */
	@Override
	public List<WxShopInforDto> wxPageList(String searchValue, Long typeId, String label) {
		List<WxShopInforDto> list = wxShopInforDao.findPage(searchValue, typeId);
		List<WxShopInforDto> retList = new ArrayList<>();
		List<WxShopType> shopTypeList = wxShopTypeService.findByNamedParamList(null);
		if (null != list && list.size() > 0) {
			// 查询有结果
			for (WxShopInforDto wxShopInforDto : list) {
				if (!StringUtils.isEmpty(label)) {
					// 通过 标签进行检索数据
					if (!StringUtils.isEmpty(wxShopInforDto.getLabel())) {
						if (wxShopInforDto.getLabel().contains(",")) {
							// 有多个 label
							String[] labelIds = wxShopInforDto.getLabel().split(",");
							for (int i = 0; i < labelIds.length; i++) {
								if (!StringUtils.isEmpty(labelIds[i]) && labelIds[i].equals(label)) {
									// 符合条件
									editWxShopInforDto(wxShopInforDto, shopTypeList);
									retList.add(wxShopInforDto);
									// 终断循环
									break;
								}
							}
						} else {
							// 有一个label
							if (wxShopInforDto.getLabel().equals(label)) {
								// 符合条件
								editWxShopInforDto(wxShopInforDto, shopTypeList);
								retList.add(wxShopInforDto);
							}
						}
					}
				} else {
					// 不通过标签进行数据检索
					editWxShopInforDto(wxShopInforDto, shopTypeList);
					retList.add(wxShopInforDto);
				}
			}
		}
		return retList;
	}

	/**
	 * 校验商铺是否存在
	 * 
	 * @param id
	 *            店铺主键
	 * @param code
	 *            商铺的门牌号
	 */
	@Override
	public boolean checkWxShopInfor(Long id, String code) {
		boolean result = true;
		WxShopInfor wxShopInfor = this.makeWxShopInfor(Long.valueOf(0), null, code, Long.valueOf(0), null, null, null,
				null, null, null, 0, 1);
		WxShopInfor wxShopInforExist = wxShopInforDao.findByNamedParam(wxShopInfor);
		if (null == wxShopInforExist) {
			result = false;
		} else {
			if (wxShopInforExist.getId() == id) {
				result = false;
			}
		}
		return result;
	}

	/**
	 * 新建商铺或者更新商铺
	 * 
	 * @param id
	 *            店铺主键
	 * @param name
	 *            商铺名称
	 * @param code
	 *            商铺的门牌号
	 * @param typeId
	 *            商铺的种类
	 * @param labelIds
	 *            商铺的标签
	 * @param telephone
	 *            商铺的联系电话
	 * @param introduce
	 *            商铺的简介
	 * @param wechat
	 *            商铺的微信号
	 * @param shopMap
	 *            商铺的主图
	 * @param shopMapName
	 *            商铺的主图图片名称
	 * @param shopImage
	 *            商铺的印象图
	 * @param shopImageName
	 *            商铺的印象图图片名称
	 * @param top
	 *            查询时商铺是否置顶显示
	 */
	@Override
	public void addOrUpdateWxShopInfor(Long id, String name, String code, Long typeId, List<String> labelIds,
			String telephone, String introduce, String wechat, String shopMap, String shopMapName, Integer top) {
		WxShopInfor wxShopInfor = this.makeWxShopInfor(id, name, code, typeId, labelIds, telephone, introduce, wechat,
				shopMap, shopMapName, top, 0);
		if (id == 0) {
			wxShopInforDao.create(wxShopInfor);
		} else {
			wxShopInforDao.update(wxShopInfor);
		}
	}

	/**
	 * 商铺信息编辑
	 * 
	 * @param id
	 *            店铺主键
	 * @param name
	 *            商铺名称
	 * @param code
	 *            商铺的门牌号
	 * @param typeId
	 *            商铺的种类
	 * @param labelIds
	 *            商铺的标签
	 * @param telephone
	 *            商铺的联系电话
	 * @param introduce
	 *            商铺的简介
	 * @param wechat
	 *            商铺的微信号
	 * @param shopMap
	 *            商铺的主图
	 * @param shopMapName
	 *            商铺的主图图片名称
	 * @param shopImage
	 *            商铺的印象图
	 * @param shopImageName
	 *            商铺的印象图图片名称
	 * @param top
	 *            查询时商铺是否置顶显示
	 * @param status
	 *            商铺的状态
	 */
	@Override
	public WxShopInfor makeWxShopInfor(Long id, String name, String code, Long typeId, List<String> labelIds,
			String telephone, String introduce, String wechat, String shopMap, String shopMapName, Integer top,
			Integer status) {
		WxShopInfor wxShopInfor = new WxShopInfor();
		if (id > 0) { // 主键ID
			wxShopInfor.setId(id);
		}
		if (!StringUtils.isEmpty(name)) {
			wxShopInfor.setName(name);
		}
		if (!StringUtils.isEmpty(code)) {
			wxShopInfor.setCode(code);
		}
		if (null != typeId && Long.valueOf(typeId) > 0) {
			wxShopInfor.setTypeId(typeId);
		}
		if (null != labelIds && labelIds.size() > 0) {
			String labelIdS = labelIds.stream().collect(Collectors.joining(","));
			wxShopInfor.setLabel(labelIdS);
		}
		if (!StringUtils.isEmpty(telephone)) {
			wxShopInfor.setTelephone(telephone);
		}
		if (!StringUtils.isEmpty(introduce)) {
			wxShopInfor.setIntroduce(introduce);
		}
		if (!StringUtils.isEmpty(wechat)) {
			wxShopInfor.setWechat(wechat);
		}
		if (!StringUtils.isEmpty(shopMap)) {
			wxShopInfor.setShopMap(shopMap);
		}
		if (!StringUtils.isEmpty(shopMapName)) {
			wxShopInfor.setShopMapName(shopMapName);
		}
		if (null != top && Integer.valueOf(top) > 0) {
			wxShopInfor.setTop(Integer.valueOf(top));
		}
		if (null != status && status > 0) {
			wxShopInfor.setStatus(Integer.valueOf(status));
		}
		return wxShopInfor;
	}

	/**
	 * 更新商铺的状态
	 * 
	 * @param id
	 *            商铺主键
	 */
	@Override
	public void updateStatusById(Long id) {
		WxShopInfor wxShopInfor = this.makeWxShopInfor(id, null, null, Long.valueOf(0), null, null, null, null, null,
				null, 0, 2);
		wxShopInforDao.update(wxShopInfor);
		// 删除店铺中对应的商品
		wxShopItemService.updateStatusByPId(id);
	}

	/**
	 * 根据标签查找商铺
	 * 
	 * @param label
	 *            商铺的标签
	 */
	@Override
	public List<WxShopInfor> findByLabel(String label) {
		return wxShopInforDao.findByLabel(label);
	}

	/**
	 * 商铺的种类和标签更新
	 * 
	 * @param typeId
	 *            店铺的标签
	 */
	@Override
	public void cleanTypeAndLabelByTypeId(Long typeId) {
		wxShopInforDao.cleanTypeAndLabelByTypeId(typeId);
	}

	/**
	 * 商铺的详细信息取得
	 * 
	 * @param id
	 *            店铺的主键
	 */
	@Override
	public WxShopInforDto findWxShopInforDtoById(Long id) {
		WxShopInfor wxShopInfor = wxShopInforDao.findById(id);
		WxShopInforDto wxShopInforDto = null;
		if (null != wxShopInfor) {
			List<WxShopType> shopTypeList = wxShopTypeService.findByNamedParamList(null);
			wxShopInforDto = this.makeWxShopInforDto(wxShopInfor, shopTypeList);
		} else {
			wxShopInforDto = new WxShopInforDto();
		}
		return wxShopInforDto;
	}

	/**
	 * 微信端查看商铺的详细信息
	 * 
	 * @param id
	 *            店铺的主键
	 */
	@Override
	public WxShopInforAppDto wxFindById(Long id) {
		WxShopInforAppDto wxShopInforAppDto = new WxShopInforAppDto();
		wxShopInforAppDto.setWxShopInforDto(this.findWxShopInforDtoById(id));
		WxShopItem wxShopItem = new WxShopItem();
		wxShopItem.setPId(id);
		wxShopItem.setStatus(1);
		List<WxShopItem> listItem = wxShopItemService.findByNamedParamList(wxShopItem);
		if (null != listItem && listItem.size() > 0) {
			wxShopInforAppDto.setItemList(listItem);
		}
		return wxShopInforAppDto;
	}

	/**
	 * 商铺的详细信息编辑
	 * 
	 * @param wxShopInfor
	 *            店铺的信息
	 * @param shopTypeList
	 *            店铺的种类和标签
	 */
	@Override
	public WxShopInforDto makeWxShopInforDto(WxShopInfor wxShopInfor, List<WxShopType> shopTypeList) {
		WxShopInforDto wxShopInforDto = new WxShopInforDto();
		if (!StringUtils.isEmpty(wxShopInfor.getLabel())) {
			List<String> labelName = new ArrayList<>();
			if (wxShopInfor.getLabel().contains(",")) {
				// 有多个 标签
				String[] labelIds = wxShopInfor.getLabel().split(",");
				for (int i = 0; i < labelIds.length; i++) {
					String labelId = labelIds[i];
					WxShopType findDto = shopTypeList.stream()
							.filter(labelDtoStream -> labelDtoStream.getId() == Long.valueOf(labelId)).findFirst()
							.orElse(null);
					if (null != findDto) {
						labelName.add(findDto.getTypename());
					}
				}
			} else {
				// 有一个标签
				WxShopType findDto = shopTypeList.stream()
						.filter(labelDtoStream -> labelDtoStream.getId() == Long.valueOf(wxShopInfor.getLabel()))
						.findFirst().orElse(null);
				if (null != findDto) {
					labelName.add(findDto.getTypename());
				}
			}
			String labelIdNameS = labelName.stream().collect(Collectors.joining(","));
			wxShopInforDto.setLabelName(labelIdNameS);
		}
		wxShopInforDto.setId(wxShopInfor.getId());
		wxShopInforDto.setCode(wxShopInfor.getCode());
		wxShopInforDto.setIntroduce(wxShopInfor.getIntroduce());
		wxShopInforDto.setLabel(wxShopInfor.getLabel());
		wxShopInforDto.setTypeId(wxShopInfor.getTypeId());
		if (null != wxShopInfor.getTypeId()) {
			WxShopType findDto = shopTypeList.stream()
					.filter(typeDtoStream -> typeDtoStream.getId() == wxShopInfor.getTypeId()).findFirst().orElse(null);
			if (null != findDto) {
				wxShopInforDto.setTypeName(findDto.getTypename());
			}
		}
		wxShopInforDto.setName(wxShopInfor.getName());
		wxShopInforDto.setShopMap(wxShopInfor.getShopMap());
		wxShopInforDto.setShopMapName(wxShopInfor.getShopMapName());
		wxShopInforDto.setStatus(wxShopInfor.getStatus());
		wxShopInforDto.setTelephone(wxShopInfor.getTelephone());
		wxShopInforDto.setTop(wxShopInfor.getTop());
		wxShopInforDto.setWechat(wxShopInfor.getWechat());
		return wxShopInforDto;
	}

	/**
	 * 商铺的详细信息编辑
	 * 
	 * @param wxShopInforDto
	 *            店铺的信息
	 * @param shopTypeList
	 *            店铺的种类和标签
	 */
	@Override
	public void editWxShopInforDto(WxShopInforDto wxShopInforDto, List<WxShopType> shopTypeList) {
		// 编辑标签
		if (!StringUtils.isEmpty(wxShopInforDto.getLabel())) {
			List<String> labelName = new ArrayList<>();
			if (wxShopInforDto.getLabel().contains(",")) {
				// 有多个 标签
				String[] labelIds = wxShopInforDto.getLabel().split(",");
				for (int i = 0; i < labelIds.length; i++) {
					String labelId = labelIds[i];
					WxShopType findDto = shopTypeList.stream()
							.filter(labelDtoStream -> labelDtoStream.getId() == Long.valueOf(labelId)).findFirst()
							.orElse(null);
					if (null != findDto) {
						labelName.add(findDto.getTypename());
					}
				}
			} else {
				// 有一个标签
				WxShopType findDto = shopTypeList.stream()
						.filter(labelDtoStream -> labelDtoStream.getId() == Long.valueOf(wxShopInforDto.getLabel()))
						.findFirst().orElse(null);
				if (null != findDto) {
					labelName.add(findDto.getTypename());
				}
			}
			String labelIdNameS = labelName.stream().collect(Collectors.joining(","));
			wxShopInforDto.setLabelName(labelIdNameS);
		}

		// 编辑种类
		if (!StringUtils.isEmpty(wxShopInforDto.getTypeId())) {
			WxShopType findDto = shopTypeList.stream()
					.filter(typeDtoStream -> typeDtoStream.getId() == wxShopInforDto.getTypeId()).findFirst()
					.orElse(null);
			if (null != findDto) {
				wxShopInforDto.setTypeName(findDto.getTypename());
			}
		}
	}
}
