package com.weChatmarket.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.weChatmarket.dao.WxShopItemDao;
import com.weChatmarket.domain.WxShopItem;
import com.weChatmarket.page.BasePage;
import com.weChatmarket.service.WxShopItemService;

/**
 * 商品详细信息表 create by dongshize
 */
@Service("wxShopItemService")
public class WxShopItemServiceImpl extends BaseServiceImpl<WxShopItem> implements WxShopItemService {

	@Autowired
	private WxShopItemDao wxShopItemDao;

	@SuppressWarnings("unchecked")
	@Override
	public WxShopItemDao getDao() {
		return wxShopItemDao;
	}

	/**
	 * 商品信息的新增或更新
	 * 
	 * @param id
	 *            商品主键
	 * @param pId
	 *            商铺的主鍵
	 * @param title
	 *            商品的标题
	 * @param content
	 *            商品的内容
	 * @param photoId
	 *            商品的图片
	 */
	@Override
	public void addOrUpdateWxShopItem(Long id, Long pId, String title, String content, String photoId,
			String photoName) {
		WxShopItem wxShopItem = this.makeWxShopItem(id, pId, title, content, photoId, photoName, 0);
		if (id == 0) {
			wxShopItemDao.create(wxShopItem);
		} else {
			wxShopItemDao.update(wxShopItem);
		}
	}

	/**
	 * 商品信息的编辑
	 * 
	 * @param id
	 *            商品主键
	 * @param pId
	 *            商铺的主鍵
	 * @param title
	 *            商品的标题
	 * @param content
	 *            商品的内容
	 * @param photoId
	 *            商品的图片
	 * @param status
	 *            商品的状态
	 */
	@Override
	public WxShopItem makeWxShopItem(Long id, Long pId, String title, String content, String photoId, String photoName,
			Integer status) {
		WxShopItem wxShopItem = new WxShopItem();
		if (null != id && id > 0) { // 主键ID
			wxShopItem.setId(id);
		}
		if (null != pId && pId > 0) {
			wxShopItem.setPId(pId);
		}
		if (!StringUtils.isEmpty(title)) {
			wxShopItem.setTitle(title);
		}
		if (!StringUtils.isEmpty(content)) {
			wxShopItem.setContent(content);
		}
		if (!StringUtils.isEmpty(photoId)) {
			wxShopItem.setPhotoId(photoId);
		}
		if (!StringUtils.isEmpty(photoName)) {
			wxShopItem.setPhotoName(photoName);
		}
		if (null != status && status > 0) {
			wxShopItem.setStatus(status);
		}
		return wxShopItem;
	}

	/**
	 * 商品的状态变更
	 * 
	 * @param id
	 *            商品主键
	 */
	@Override
	public void updateStatusById(Long id) {
		WxShopItem wxShopItem = this.makeWxShopItem(id, Long.valueOf(0), null, null, null, null, 2);
		wxShopItemDao.update(wxShopItem);
	}

	/**
	 * 商品信息的编辑
	 * 
	 * @param id
	 *            商品主键
	 * @param pId
	 *            商铺的主鍵
	 * @param title
	 *            商品的标题
	 * @param content
	 *            商品的内容
	 * @param photoId
	 *            商品的图片
	 * @param status
	 *            商品的状态
	 */
	@Override
	public BasePage<WxShopItem> findPage(Integer pageNum, Integer pageSize, Long pId) {
		PageHelper.startPage(pageNum, pageSize);
		List<WxShopItem> list = wxShopItemDao.findPage(pId);
		return new BasePage<WxShopItem>(list);
	}

	/**
	 * 商品信息的删除
	 * 
	 * @param pId
	 *            商铺的主鍵
	 */
	@Override
	public void updateStatusByPId(Long pId) {
		wxShopItemDao.updateStatusByPId(pId);
	}
}
