package com.weChatmarket.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import javax.annotation.Resource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.weChatmarket.dao.WxShopTypeDao;
import com.weChatmarket.domain.WxShopInfor;
import com.weChatmarket.domain.WxShopType;
import com.weChatmarket.dto.WxShopLableDto;
import com.weChatmarket.dto.WxShopTypeLableDto;
import com.weChatmarket.page.BasePage;
import com.weChatmarket.service.WxShopInforService;
import com.weChatmarket.service.WxShopTypeService;

/**
 * 商铺种类表 create by dongshize
 */
@Service("wxShopTypeService")
public class WxShopTypeServiceImpl extends BaseServiceImpl<WxShopType> implements WxShopTypeService {

	@Autowired
	private WxShopTypeDao wxShopTypeDao;
	@Resource
	private WxShopInforService wxShopInforService;

	@SuppressWarnings("unchecked")
	@Override
	public WxShopTypeDao getDao() {
		return wxShopTypeDao;
	}
	
	/**
	 *  校验种类或标签是否存在
	 * 
	 * @param id 种类的主键
	 * @param typeName 种类的名称
	 */
	@Override
	public boolean checkWxShopType(Long pId, String typeName) {
		boolean result = true;
		WxShopType wxShopType = this.makeWxShopType(Long.valueOf(0), Long.valueOf(pId), typeName, 1);
		WxShopType wxShopTypeExist = wxShopTypeDao.findByNamedParam(wxShopType);
		if (null == wxShopTypeExist) {
			result = false;
		}
		return result;
	}
	
	/**
	 *  种类或标签的添加或更新
	 *  
	 * @param id 种类主键
	 * @param pId 父类主键
	 * @param typeName 种类名称
	 */
	@Override
	public void addOrUpdateWxShopType(Long id, Long pId, String typeName) {
		WxShopType wxShopType = this.makeWxShopType(id, pId, typeName, 0);
		if (id == 0) {
			wxShopTypeDao.create(wxShopType);
		} else {
			wxShopTypeDao.update(wxShopType);
		}
	}

	/**
	 *  种类或标签的编辑
	 *  
	 * @param id 种类的主键
	 * @param pId 商铺主键
	 * @param typeName 种类名称
	 * @param status 种类的状态
	 */
	@Override
	public WxShopType makeWxShopType(Long id, Long pId, String typeName, Integer status) {
		WxShopType wxShopType = new WxShopType();
		if (id > 0) { // 主键ID
			wxShopType.setId(id);
		}
		if (null != pId && pId > -1) { // 父类的主键ID
			wxShopType.setPId(pId);
		}
		if (!StringUtils.isEmpty(typeName)) {
			wxShopType.setTypename(typeName);
		}
		if (null != status && status > 0) {
			wxShopType.setStatus(status);
		}
		return wxShopType;
	}

	/**
	 *  种类或标签的取得
	 *  
	 * @param id 种类的主键
	 */
	
	@Override
	public WxShopType findWxShopTypeById(Long id) {
		return wxShopTypeDao.findById(id);
	}

	/**
	 *  种类或标签的状态更新
	 *  
	 * @param id 种类的主键
	 * @param pId 父类主键
	 */
	@Override
	public void updateStatusById(Long id, Long pId) {
		wxShopTypeDao.updateStatusById(id);
		// 类别删除
		if (null != pId && pId == 0) {
			// 删除的是类别，类别下面对应的标签全部删除
			wxShopTypeDao.updateStatusByPid(id);
			// 商店中对应的类别也相应清空，并且标签也相应的清空
			wxShopInforService.cleanTypeAndLabelByTypeId(id);
		} else {
			// 标签删除
			// 商城里面对应的标签进行删除
			List<WxShopInfor> wxShopInforList = wxShopInforService.findByLabel(String.valueOf(id));
			for (WxShopInfor shopInf : wxShopInforList) {
				String lables = shopInf.getLabel();
				if (!StringUtils.isEmpty(lables)) {
					String lableNew = "";
					if (lables.contains(",")) {
						String[] lableTeam = lables.split(",");
						List<String> lableList = new ArrayList<>();
						for (int i = 0; i < lableTeam.length; i++) {
							if (!lableTeam[i].equals(String.valueOf(id))) {
								lableList.add(lableTeam[i]);
							}
						}
						lableNew = lableList.stream().collect(Collectors.joining(","));
						shopInf.setLabel(lableNew);
						// 更新数据
						wxShopInforService.update(shopInf);
					} else {
						// 里面只有一个
						if (String.valueOf(id).equals(lables)) {
							// 设定新的label
							shopInf.setLabel(lableNew);
							// 更新数据
							wxShopInforService.update(shopInf);
						}
					}
				}
			}
		}
	}
	
	/**
	 * 所有标签查询-分页
	 * 
	 * @param pageNum 页码
	 * @param pageSize 每页数量
	 * @param pId 父类主键
	 */
	@Override
	public BasePage<WxShopType> lablePageList(Integer pageNum, Integer pageSize,Long pId) {
		PageHelper.startPage(pageNum, pageSize);
		WxShopType WxShopType = new WxShopType();
		WxShopType.setPId(pId);
		WxShopType.setStatus(1);
		List<WxShopType> list = wxShopTypeDao.findByNamedParamList(WxShopType);
		return new BasePage<WxShopType>(list);
	}
	
	/**
	 * 所有种类查询-分页
	 * 
	 * @param pageNum 页码
	 * @param pageSize 每页数量
	 */
	@Override
	public BasePage<WxShopType> typePageList(Integer pageNum, Integer pageSize) {
		PageHelper.startPage(pageNum, pageSize);
		List<WxShopType> list = wxShopTypeDao.findTypeList(null);
		return new BasePage<WxShopType>(list);
	}
	
	/**
	 * 所有种类或标签查询
	 */
	@Override
	public List<WxShopTypeLableDto> wxTypeLableList() {
		List<WxShopTypeLableDto> list = new ArrayList<>();
		WxShopTypeLableDto wxShopTypeLableDto = null;
		// 父类
		List<WxShopType> father = wxShopTypeDao.findTypeList(null);
		for (WxShopType wxShopType : father) {
			wxShopTypeLableDto = new WxShopTypeLableDto();
			wxShopTypeLableDto.setId(wxShopType.getId());
			wxShopTypeLableDto.setText(wxShopType.getTypename());
			wxShopTypeLableDto.setpId(wxShopType.getPId());
			wxShopTypeLableDto.setStatus(wxShopType.getStatus());
			List<WxShopLableDto> children = new ArrayList<>();
			// 子类
			WxShopType WxShopTypeSon = new WxShopType();
			WxShopTypeSon.setPId(wxShopType.getId());
			WxShopTypeSon.setStatus(1);
			List<WxShopType> lableList = wxShopTypeDao.findByNamedParamList(WxShopTypeSon);
			for (WxShopType chShopType : lableList) {
				WxShopLableDto wxShopLableDto = new WxShopLableDto();
				wxShopLableDto.setId(chShopType.getId());
				wxShopLableDto.setText(chShopType.getTypename());
				wxShopLableDto.setpId(chShopType.getPId());
				wxShopLableDto.setStatus(chShopType.getStatus());
				children.add(wxShopLableDto);
			}
			wxShopTypeLableDto.setChildren(children);
			list.add(wxShopTypeLableDto);
		}
		return list;
	}

	/**
	 * 所有种类查询
	 * 
	 * @param typename 种类名称
	 */
	@Override
	public List<WxShopType> typeList(String typename) {
		List<WxShopType> list = wxShopTypeDao.findTypeList(typename);
		return list;
	}
	
	/**
	 * 所有标签查询
	 * 
	 * @param pId 父类主键
	 */
	@Override
	public List<WxShopType> lableList(Long pId) {
		WxShopType WxShopType = new WxShopType();
		WxShopType.setPId(pId);
		WxShopType.setStatus(1);
		List<WxShopType> list = wxShopTypeDao.findByNamedParamList(WxShopType);
		return list;
	}
}
